From 1637ee73ed2ead8fac258996b9e05f18bfc33136 Mon Sep 17 00:00:00 2001
From: Matt <matt@excalamus.com>
Date: Tue, 20 Dec 2022 15:22:38 -0500
Subject: [PATCH 3/7] Refactor test-ob-shell/session

- Rename test precisely
- Rename comint from "yes" to test name*
- Clean up on success

Several notes have been placed indicating future refactoring.  Namely,
`org-babel-shell-initialize` should be a macro since it generates
functions.

* The session name should be refactored into a variable,
e.g. `session-name`.  However, when this is done,
`org-babel-execute:sh` produces a type error.  The `params` symbol in
`org-babel-execute:sh` does not evaluate as a variable for some reason
and, because of how `org-babel-execute:sh` is defined, it's difficult
to debug why.
---
 lisp/ob-shell.el              |  2 ++
 testing/lisp/test-ob-shell.el | 26 ++++++++++++++++----------
 2 files changed, 18 insertions(+), 10 deletions(-)

diff --git a/lisp/ob-shell.el b/lisp/ob-shell.el
index d38d2d335..8da9aa738 100644
--- a/lisp/ob-shell.el
+++ b/lisp/ob-shell.el
@@ -68,6 +68,8 @@ alist element.")
 
 (defvar org-babel-prompt-command)
 
+;; TODO refactor into macro.  Currently violates (elisp) Coding
+;; Conventions and is hard to debug.
 (defun org-babel-shell-initialize ()
   "Define execution functions associated to shell names.
 This function has to be called whenever `org-babel-shell-names'
diff --git a/testing/lisp/test-ob-shell.el b/testing/lisp/test-ob-shell.el
index 625dc64b9..ecdc461d3 100644
--- a/testing/lisp/test-ob-shell.el
+++ b/testing/lisp/test-ob-shell.el
@@ -29,8 +29,8 @@
   (signal 'missing-test-dependency "Support for Shell code blocks"))
 
 (ert-deftest test-ob-shell/dont-insert-spaces-on-expanded-bodies ()
-  "Expanded shell bodies should not start with a blank line
-unless the body of the tangled block does."
+  "Expanded shell bodies should not start with a blank line unless
+the body of the tangled block does."
   (should-not (string-match "^[\n\r][\t ]*[\n\r]"
                             (org-babel-expand-body:generic "echo 2" '())))
   (should (string-match "^[\n\r][\t ]*[\n\r]"
@@ -43,18 +43,24 @@ unless the body of the tangled block does."
   (if (should (null (org-babel-execute:sh "ls NoSuchFileOrDirectory.txt" nil)))
       (kill-buffer "*Org-Babel Error Output*")))
 
-(ert-deftest test-ob-shell/session ()
-  "This also tests `org-babel-comint-with-output' in
-ob-comint.el, which was not previously tested."
-  (let ((res (org-babel-execute:sh "echo 1; echo 2" '((:session . "yes")))))
+;; TODO refactor session name into variable after refactoring
+;; org-babel-execute:sh.  See comment there.
+(ert-deftest test-ob-shell/session-parameter-results-in-list ()
+  ;; single line input
+  (let ((res (org-babel-execute:sh "echo 1; echo 2" '((:session . "test-ob-shell/session-parameter-results-in-list")))))
     (should res)
     (should (listp res)))
-  ;; Test multi-line input.
+
+  ;; multi-line input
   (let ((result (org-babel-execute:sh
-                 "if true \n then \n echo yes \n fi"
-                 '((:session . "yes")))))
+                 "if true \n then \n echo test-ob-shell/session-parameter-results-in-list \n fi"
+                 '((:session . "test-ob-shell/session-parameter-results-in-list")))))
     (should result)
-    (should (string= "yes" result))))
+    (should (string= "test-ob-shell/session-parameter-results-in-list" result)))
+
+  ;; clean up
+  (let ((kill-buffer-query-functions nil))
+    (kill-buffer "test-ob-shell/session-parameter-results-in-list")))
 
 ; A list of tests using the samples in ob-shell-test.org
 (ert-deftest ob-shell/generic-uses-no-arrays ()
-- 
2.38.1

